@@ -42,7 +42,7 @@ void read_global_metadata(char* path, RecorderGlobalDef *RGD);
 
 void read_local_metadata(char* path, RecorderLocalDef *RLD);
 
-Record* read_records(char* path, int len, RecorderGlobalDef *RGD);
+Record* read_records(char* path, RecorderLocalDef* RLD, RecorderGlobalDef *RGD);
 
 void decompress_records(Record* records, int len);
 
